==> ember__destroyable-3.22.1.tgz: ember__destroyable v3.22/README.md <==
# Installation
> `npm install --save @types/ember__destroyable`

# Summary
This package contains type definitions for @ember/destroyable (https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable/v3.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable/v3/index.d.ts)
````ts
// Type definitions for non-npm package @ember/destroyable 3.22
// Project: https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable
// Definitions by: Mike North <https://github.com/mike-north>
//                 Chris Krycho <https://github.com/chriskrycho>
//                 Dan Freeman <https://github.com/dfreeman>
//                 James C. Davis <https://github.com/jamescdavis>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.7

export function associateDestroyableChild<T extends object>(parent: object, child: T): T;

export function isDestroying(destroyable: object): boolean;

export function isDestroyed(destroyable: object): boolean;

export function destroy(destroyable: object): void;

export function assertDestroyablesDestroyed(): void;

export function enableDestroyableTracking(): void;

export function registerDestructor<T extends object>(
destroyable: T,
destructor: (destroyable: T) => void
): (destroyable: T) => void;

export function unregisterDestructor<T extends object>(
destroyable: T,
destructor: (destroyable: T) => void
): void;

````

### Additional Details
 * Last updated: Fri, 21 Jan 2022 19:02:06 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Mike North](https://github.com/mike-north), [Chris Krycho](https://github.com/chriskrycho), [Dan Freeman](https://github.com/dfreeman), and [James C. Davis](https://github.com/jamescdavis).

==> ember__destroyable-3.22.2.tgz: ember__destroyable v3.22/README.md <==
# Installation
> `npm install --save @types/ember__destroyable`

# Summary
This package contains type definitions for @ember/destroyable (https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable/v3.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable/v3/index.d.ts)
````ts
// Type definitions for non-npm package @ember/destroyable 3.22
// Project: https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable
// Definitions by: Mike North <https://github.com/mike-north>
//                 Chris Krycho <https://github.com/chriskrycho>
//                 Krystan HuffMenne <https://github.com/gitKrystan>
//                 James C. Davis <https://github.com/jamescdavis>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 3.7

export function associateDestroyableChild<T extends object>(parent: object, child: T): T;

export function isDestroying(destroyable: object): boolean;

export function isDestroyed(destroyable: object): boolean;

export function destroy(destroyable: object): void;

export function assertDestroyablesDestroyed(): void;

export function enableDestroyableTracking(): void;

export function registerDestructor<T extends object>(
    destroyable: T,
    destructor: (destroyable: T) => void,
): (destroyable: T) => void;

export function unregisterDestructor<T extends object>(destroyable: T, destructor: (destroyable: T) => void): void;

````

### Additional Details
 * Last updated: Tue, 13 Jun 2023 20:03:07 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Mike North](https://github.com/mike-north), [Chris Krycho](https://github.com/chriskrycho), [Krystan HuffMenne](https://github.com/gitKrystan), and [James C. Davis](https://github.com/jamescdavis).
